@@ -61,7 +61,7 @@ setMethod(".glabel",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow()
-              add(container, obj)
+              add(container, obj,...)
             }
             
             invisible(obj)
